import 'package:url/url.dart';
import 'package:test/test.dart';

void main() {
  test('Good URL validity', () {
    final url = Url.parse('https://pattle.im:343/about?test=42#somewhere');
    expect(url.hasScheme, isTrue);
    expect(url.scheme == 'https', isTrue);

    expect(url.host == 'pattle.im', isTrue);

    expect(url.hasPort, isTrue);
    expect(url.port == 343, isTrue);

    expect(url.hasQuery, isTrue);
    expect(url.queryParameters['test'] == '42', isTrue);

    expect(url.hasFragment, isTrue);
    expect(url.fragment == 'somewhere', isTrue);
  });

  test('Wrong URL validity', () {
    expect(() => Url.parse('pattle.im'), throwsFormatException);
    expect(() => Url.parse('asdasd234'), throwsFormatException);
    expect(() => Url.parse('p@ttle.im'), throwsFormatException);
  });

  test('Resolve URL', () {
    final base = Url.parse('https://pattle.im');
    final to = Url.parse('https://matrix.org/blog/home');

    final destination = base.resolveUrl(to);
    expect(destination.path == '/blog/home', isTrue);
  });
}
